@@ -13,6 +13,7 @@
 # under the License.
 
 import itertools
+import logging
 import os.path
 import re
 import subprocess
@@ -128,6 +129,11 @@ class Base(base.TestCase):
         self._run_git('add', '.')
         self._run_git('commit', '-m', message)
 
+    def _add_other_file(self, name):
+        with open(os.path.join(self.reporoot, name), 'w') as f:
+            f.write('adding %s\n' % name)
+        self._git_commit('add %s' % name)
+
     def _add_notes_file(self, slug='slug', commit=True, legacy=False):
         n = self.get_note_num()
         if legacy:
@@ -156,6 +162,13 @@ class Base(base.TestCase):
 
     def setUp(self):
         super(Base, self).setUp()
+        self.logger = self.useFixture(
+            fixtures.FakeLogger(
+                format='%(levelname)8s %(name)s %(message)s',
+                level=logging.DEBUG,
+                nuke_handlers=True,
+            )
+        )
         # Older git does not have config --local, so create a temporary home
         # directory to permit using git config --global without stepping on
         # developer configuration.
@@ -206,6 +219,23 @@ class BasicTest(Base):
             results,
         )
 
+    def test_note_before_tag(self):
+        filename = self._add_notes_file()
+        self._add_other_file('not-a-release-note.txt')
+        self._run_git('tag', '-s', '-m', 'first tag', '1.0.0')
+        raw_results = scanner.get_notes_by_version(
+            self.reporoot,
+            'releasenotes/notes',
+        )
+        results = {
+            k: [f for (f, n) in v]
+            for (k, v) in raw_results.items()
+        }
+        self.assertEqual(
+            {'1.0.0': [filename]},
+            results,
+        )
+
     def test_note_commit_tagged(self):
         filename = self._add_notes_file()
         self._run_git('tag', '-s', '-m', 'first tag', '1.0.0')
@@ -239,6 +269,24 @@ class BasicTest(Base):
             results,
         )
 
+    def test_other_commit_after_tag(self):
+        filename = self._add_notes_file()
+        self._add_other_file('ignore-1.txt')
+        self._run_git('tag', '-s', '-m', 'first tag', '1.0.0')
+        self._add_other_file('ignore-2.txt')
+        raw_results = scanner.get_notes_by_version(
+            self.reporoot,
+            'releasenotes/notes',
+        )
+        results = {
+            k: [f for (f, n) in v]
+            for (k, v) in raw_results.items()
+        }
+        self.assertEqual(
+            {'1.0.0': [filename]},
+            results,
+        )
+
     def test_multiple_notes_after_tag(self):
         self._make_python_package()
         self._run_git('tag', '-s', '-m', 'first tag', '1.0.0')
@@ -314,7 +362,6 @@ class BasicTest(Base):
         }
         self.assertEqual(
             {'2.0.0': [f2],
-             '2.0.0-1': [],
              },
             results,
         )
@@ -337,7 +384,6 @@ class BasicTest(Base):
         }
         self.assertEqual(
             {'2.0.0': [f2],
-             '2.0.0-1': [],
              },
             results,
         )
@@ -360,7 +406,6 @@ class BasicTest(Base):
         }
         self.assertEqual(
             {'2.0.0': [f1],
-             '2.0.0-1': [],
              },
             results,
         )
@@ -383,7 +428,6 @@ class BasicTest(Base):
         }
         self.assertEqual(
             {'2.0.0': [f2],
-             '2.0.0-1': [],
              },
             results,
         )
@@ -409,7 +453,6 @@ class BasicTest(Base):
         }
         self.assertEqual(
             {'2.0.0': [f2],
-             '2.0.0-1': [],
              },
             results,
         )
